@@ -53,7 +53,7 @@ impl From<fvm_ipld_encoding::Error> for ActorError {
 
 /// Converts an actor deletion error into an actor error with the appropriate exit code. This
 /// facilitates propagation.
-#[cfg(feature = "fil-actor")]
+#[cfg(target_arch = "wasm32")]
 impl From<fvm_sdk::error::ActorDeleteError> for ActorError {
     fn from(e: fvm_sdk::error::ActorDeleteError) -> Self {
         use fvm_sdk::error::ActorDeleteError::*;
@@ -71,7 +71,7 @@ impl From<fvm_sdk::error::ActorDeleteError> for ActorError {
 
 /// Converts a no-state error into an an actor error with the appropriate exit code (illegal actor).
 /// This facilitates propagation.
-#[cfg(feature = "fil-actor")]
+#[cfg(target_arch = "wasm32")]
 impl From<fvm_sdk::error::NoStateError> for ActorError {
     fn from(e: fvm_sdk::error::NoStateError) -> Self {
         Self {
