@@ -30,7 +30,7 @@ use fvm_shared::version::NetworkVersion;
 use fvm_shared::{ActorID, MethodNum};
 
 use crate::runtime::{ActorCode, MessageInfo, Policy, Runtime, RuntimePolicy, Syscalls};
-use crate::{actor_error, ActorError};
+use crate::{actor_error, ActorError, SYS_FORBIDDEN, SYS_ILLEGAL_ACTOR};
 
 lazy_static! {
     pub static ref SYSTEM_ACTOR_CODE_ID: Cid = make_builtin(b"fil/test/system");
@@ -514,9 +514,13 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
             }
         }
         expectations.expect_validate_caller_addr = None;
-        return Err(actor_error!(SysErrForbidden;
+        return Err(ActorError::new(
+            SYS_FORBIDDEN,
+            format!(
                 "caller address {:?} forbidden, allowed: {:?}",
-                self.message().caller(), &addrs
+                self.message().caller(),
+                &addrs
+            ),
         ));
     }
     fn validate_immediate_caller_type<'a, I>(&mut self, types: I) -> Result<(), ActorError>
@@ -554,8 +558,10 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
 
         self.expectations.borrow_mut().expect_validate_caller_type = None;
 
-        Err(actor_error!(SysErrForbidden; "caller type {:?} forbidden, allowed: {:?}",
-                self.caller_type, types))
+        Err(ActorError::new(
+            SYS_FORBIDDEN,
+            format!("caller type {:?} forbidden, allowed: {:?}", self.caller_type, types),
+        ))
     }
 
     fn current_balance(&self) -> TokenAmount {
@@ -598,7 +604,7 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
 
     fn create<C: Cbor>(&mut self, obj: &C) -> Result<(), ActorError> {
         if self.state.is_some() {
-            return Err(actor_error!(SysErrIllegalActor; "state already constructed"));
+            panic!("state shouldn't have been set")
         }
         self.state = Some(self.store.put_cbor(obj, Code::Blake2b256).unwrap());
         Ok(())
@@ -614,7 +620,7 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
         F: FnOnce(&mut C, &mut Self) -> Result<RT, ActorError>,
     {
         if self.in_transaction {
-            return Err(actor_error!(SysErrIllegalActor; "nested transaction"));
+            panic!("recursive transaction")
         }
         let mut read_only = self.state()?;
         self.in_transaction = true;
@@ -639,7 +645,10 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
     ) -> Result<RawBytes, ActorError> {
         self.require_in_call();
         if self.in_transaction {
-            return Err(actor_error!(SysErrIllegalActor; "side-effect within transaction"));
+            return Err(ActorError::new(
+                SYS_ILLEGAL_ACTOR,
+                "side-effect within transaction".into(),
+            ));
         }
 
         assert!(
@@ -660,7 +669,7 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
         {
             let mut balance = self.balance.borrow_mut();
             if value > *balance {
-                return Err(actor_error!(SysErrSenderStateInvalid;
+                return Err(actor_error!(SYS_SENDER_STATE_INVALID;
                         "cannot send value: {:?} exceeds balance: {:?}",
                         value, *balance
                 ));
@@ -669,7 +678,7 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
         }
 
         match expected_msg.exit_code {
-            ExitCode::Ok => Ok(expected_msg.send_return),
+            ExitCode::OK => Ok(expected_msg.send_return),
             x => Err(ActorError::new(x, "Expected message Fail".to_string())),
         }
     }
@@ -684,7 +693,10 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
     fn create_actor(&mut self, code_id: Cid, actor_id: ActorID) -> Result<(), ActorError> {
         self.require_in_call();
         if self.in_transaction {
-            return Err(actor_error!(SysErrIllegalActor; "side-effect within transaction"));
+            return Err(ActorError::new(
+                SYS_ILLEGAL_ACTOR,
+                "side-effect within transaction".into(),
+            ));
         }
         let expect_create_actor = self
             .expectations
@@ -700,7 +712,10 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
     fn delete_actor(&mut self, addr: &Address) -> Result<(), ActorError> {
         self.require_in_call();
         if self.in_transaction {
-            return Err(actor_error!(SysErrIllegalActor; "side-effect within transaction"));
+            return Err(ActorError::new(
+                SYS_ILLEGAL_ACTOR,
+                "side-effect within transaction".into(),
+            ));
         }
         let exp_act = self.expectations.borrow_mut().expect_delete_actor.take();
         if exp_act.is_none() {
@@ -798,22 +813,22 @@ impl Syscalls for MockRuntime {
     ) -> anyhow::Result<Cid> {
         let exp =
             self.expectations.borrow_mut().expect_compute_unsealed_sector_cid.take().ok_or_else(
-                || actor_error!(ErrIllegalState; "Unexpected syscall to ComputeUnsealedSectorCID"),
+                || actor_error!(USR_ILLEGAL_STATE; "Unexpected syscall to ComputeUnsealedSectorCID"),
             )?;
 
         if exp.reg != reg {
-            return Err(anyhow!(actor_error!(ErrIllegalState;
+            return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE;
                 "Unexpected compute_unsealed_sector_cid : reg mismatch"
             )));
         }
 
         if exp.pieces[..].eq(pieces) {
-            return Err(anyhow!(actor_error!(ErrIllegalState;
+            return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE;
                 "Unexpected compute_unsealed_sector_cid : pieces mismatch"
             )));
         }
 
-        if exp.exit_code != ExitCode::Ok {
+        if exp.exit_code != ExitCode::OK {
             return Err(anyhow!(ActorError::new(exp.exit_code, "Expected Failure".to_string(),)));
         }
         Ok(exp.cid)
@@ -821,13 +836,13 @@ impl Syscalls for MockRuntime {
     fn verify_seal(&self, seal: &SealVerifyInfo) -> anyhow::Result<()> {
         let exp =
             self.expectations.borrow_mut().expect_verify_seal.take().ok_or_else(
-                || actor_error!(ErrIllegalState; "Unexpected syscall to verify seal"),
+                || actor_error!(USR_ILLEGAL_STATE; "Unexpected syscall to verify seal"),
             )?;
 
         if exp.seal != *seal {
-            return Err(anyhow!(actor_error!(ErrIllegalState; "Unexpected seal verification"),));
+            return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE; "Unexpected seal verification"),));
         }
-        if exp.exit_code != ExitCode::Ok {
+        if exp.exit_code != ExitCode::OK {
             return Err(anyhow!(ActorError::new(exp.exit_code, "Expected Failure".to_string(),)));
         }
         Ok(())
@@ -835,13 +850,13 @@ impl Syscalls for MockRuntime {
     fn verify_post(&self, post: &WindowPoStVerifyInfo) -> anyhow::Result<()> {
         let exp =
             self.expectations.borrow_mut().expect_verify_post.take().ok_or_else(
-                || actor_error!(ErrIllegalState; "Unexpected syscall to verify PoSt"),
+                || actor_error!(USR_ILLEGAL_STATE; "Unexpected syscall to verify PoSt"),
             )?;
 
         if exp.post != *post {
-            return Err(anyhow!(actor_error!(ErrIllegalState; "Unexpected PoSt verification"),));
+            return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE; "Unexpected PoSt verification"),));
         }
-        if exp.exit_code != ExitCode::Ok {
+        if exp.exit_code != ExitCode::OK {
             return Err(anyhow!(ActorError::new(exp.exit_code, "Expected Failure".to_string(),)));
         }
         Ok(())
@@ -853,20 +868,20 @@ impl Syscalls for MockRuntime {
         extra: &[u8],
     ) -> anyhow::Result<Option<ConsensusFault>> {
         let exp = self.expectations.borrow_mut().expect_verify_consensus_fault.take().ok_or_else(
-            || actor_error!(ErrIllegalState; "Unexpected syscall to verify_consensus_fault"),
+            || actor_error!(USR_ILLEGAL_STATE; "Unexpected syscall to verify_consensus_fault"),
         )?;
         if exp.require_correct_input {
             if exp.block_header_1 != h1 {
-                return Err(anyhow!(actor_error!(ErrIllegalState; "Header 1 mismatch")));
+                return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE; "Header 1 mismatch")));
             }
             if exp.block_header_2 != h2 {
-                return Err(anyhow!(actor_error!(ErrIllegalState; "Header 2 mismatch")));
+                return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE; "Header 2 mismatch")));
             }
             if exp.block_header_extra != extra {
-                return Err(anyhow!(actor_error!(ErrIllegalState; "Header extra mismatch"),));
+                return Err(anyhow!(actor_error!(USR_ILLEGAL_STATE; "Header extra mismatch"),));
             }
         }
-        if exp.exit_code != ExitCode::Ok {
+        if exp.exit_code != ExitCode::OK {
             return Err(anyhow!(ActorError::new(exp.exit_code, "Expected Failure".to_string(),)));
         }
         Ok(exp.fault)
